/* Credits/Copyright/Reference:
-Raw Javascript (DOM)-
	http://www.w3.org/TR/DOM-Level-2-Core/
		http://www.w3.org/TR/DOM-Level-2-Core/ecma-script-binding.html (quick reference of all JS DOM features)
	http://www.w3.org/TR/DOM-Level-2-Events/
		http://www.w3.org/TR/DOM-Level-2-Events/ecma-script-binding.html (JS Events Reference)
-Raw Javascript (language)-
	http://www.ecma-international.org/publications/standards/Ecma-262.htm
		http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-262.pdf (direct link)
*/

function getId(element) {
	if(element.hasAttribute("id")) {
		return element.getAttribute("id")
	} else {
		return null
	}
}

function setup() {
	addEventToAll(document, "mousedown", collect)
	window.addEventListener("mouseup",showResult, false)
}


RESULT = new function(){
	this.list = []
	this.test = null
	this.add = function(data) {
		data.index = this.list.length
		this.list.push(data)
		if(data.currentTargetId.length > "test".length && data.currentTargetId.slice(0,4) == "test") {	//what is the test number
			this.test = data.currentTargetId.slice(0,5)
		}
	}
	this.getData = function() {
		return this.list
	}
	this.reset = function() {
		this.list=[]
	}
}
function collect(Event) {
	// EventTarget = http://www.w3.org/TR/DOM-Level-2-Events/events.html#Events-EventTarget
	// eventPhase = from http://www.w3.org/TR/DOM-Level-2-Events/events.html#Events-Event
	RESULT.add({
		"EventTarget": (Event.target+"").slice("[object ".length,-1),
		"EventTargetId": getId(Event.target),
		"eventPhase": Event.eventPhase,
		"currentTarget": (Event.currentTarget+"").slice("[object ".length,-1),
		"currentTargetId": getId(Event.currentTarget),
		})
}
function showResult() {
	resultStr = ""
	actualResultStr = ""

	EventTargetsMatched = true

	if(RESULT.test) {
		data = RESULT.getData()
		for(key in data) {
			index = data[key].index
			actualObj = data[key]
			testObj = tests[RESULT.test]
			testObjEntry = testObj[index]

			eventPhasePass = (actualObj.eventPhase == testObjEntry.phase) ? "pass" : "FAIL"
			currentTargetPass = (actualObj.currentTarget == testObjEntry.element) ? "pass" : "FAIL"
			currentTargetIdPass = (actualObj.currentTargetId == testObjEntry.elementId || (!actualObj.currentTargetId && !testObjEntry.elementId)) ? "pass" : "FAIL"

			resultStr += index+ ": eventPhase: "+eventPhasePass+"\tcurrentTarget: "+currentTargetPass+"\tcurrentTargetId: "+currentTargetIdPass+"\n"
			actualResultStr += "eventPhase: "+actualObj.eventPhase+"\tcurrentTarget: "+actualObj.currentTarget+"\tcurrentTargetId: "+actualObj.currentTargetId+"\n"

			if(EventTargetsMatched && actualObj.EventTarget==testObj.targetElement && actualObj.EventTargetId==testObj.targetElementId) {	// check EventTarget
			} else {
				//alert(actualObj.EventTarget+"=="+testObj.targetElement+" && "+actualObj.EventTargetId+"=="+testObj.targetElementId)
				EventTargetsMatched = false
			}
		}
	}
	document.getElementById("result").value = resultStr
	document.getElementById("result").value += (EventTargetsMatched) ? "\nPASS: EventTargets matched" : "\nFAIL: EventTargets did not match!!!!!!!!!"
	document.getElementById("result").value += "\n\nActual Results:\n"+actualResultStr
	RESULT.reset()
}



addEventToAll = function(node, type, func) {
	if(typeof(node) == typeof({})) {
		if(node.nodeType == 1 || node.nodeType == 9) {
			node.addEventListener(type, func, true)
			node.addEventListener(type, func, false)
		}
		if(node.hasChildNodes) {
			for (key in node.childNodes) {
				childNode = node.childNodes[key]
				addEventToAll(childNode, type, func)
			}
		}
	}
}